@@ -18,7 +18,7 @@ mod_estimation_trans_ui <- function(id, label) {
       box(
         width = 5,
         title = span(
-          "Curve fitting data options",
+          "1. Curve fitting data options",
           help_modal_button(
             ns("help_fit_data"),
             ns("help_fit_data_modal")
@@ -82,12 +82,12 @@ mod_estimation_trans_ui <- function(id, label) {
                 )
               ),
               widget_sep(),
-              actionButton(
-                ns("button_gen_table"),
-                class = "options-button",
-                style = "margin-left: -10px; margin-bottom: 0px;",
-                label = "Generate tables"
-              ),
+              # actionButton(
+              #   ns("button_gen_table"),
+              #   class = "options-button",
+              #   style = "margin-left: -10px; margin-bottom: 0px;",
+              #   label = "Generate tables"
+              # ),
               br(),
               br(),
               selectInput(
@@ -203,14 +203,104 @@ mod_estimation_trans_ui <- function(id, label) {
             rHandsontableOutput(ns("fit_var_cov_mat"))
           )
         )
-      )
+      ),
+      conditionalPanel(
+        condition = "!input.load_fit_data_check",
+        ns = ns,
+        box(
+          width = 7,
+          title = "Irradiation conditions",
+          status = "primary",
+          collapsible = TRUE,
+          col_6(
+            class = "col-inner-textinput-left",
+            textInput(
+              inputId = ns("irr_cond_irradiator_name"),
+              label = "Name of the irradiator used",
+              placeholder = NULL
+            ),
+            textAreaInput(
+              inputId = ns("irr_cond_radiation_quality"),
+              label = "Radiation quality",
+              placeholder = "e.g. Cs-137, Co-60, X-ray, etc."
+            ),
+            numericInput(
+              ns("irr_cond_dose_rate"),
+              label = "Dose rate (Gy/min)",
+              step=0.1,
+              value = NA,
+              min=0
+            ),
+            selectInput(
+              ns("irr_cond_dose_quantity"),
+              label = "Dose quantity",
+              choices = c("Please choose"="", "air kerma", "dose to water", "dose to blood")
+            ),
+            selectInput(
+              ns("cal_air_water"),
+              label = "Calibration of the source",
+              choices = c("Please choose"="", "air kerma", "water")
+            ),
+            selectInput(
+              ns("irrad_air_water"),
+              label = "Irradiation medium",
+              choices = c("Please choose"="", "air", "water")
+            ),
+            numericInput(
+              ns("max_dose_curve"),
+              label = "Maximum dose curve (Gy)",
+              step=0.1,
+              value = NA,
+              min=0
+            )
+          )
+          ,
+          col_6(
+            class = "col-inner-textinput-right",
+            textInput(
+              inputId = ns("irr_cond_whole_blood"),
+              label = "Whole blood or isolated lymphocytes",
+              placeholder = NULL
+            ),
+            numericInput(
+              ns("irr_cond_temperature"),
+              label = "Temperature (\u00B0C) during irradiation",
+              step=1,
+              value = NA,
+              min=0,
+              max = 40
+            ),
+            numericInput(
+              ns("irr_cond_time"),
+              label = "Time of incubation (h) at 37(\u00B0C) after irradiation"  ,
+              step=1,
+              value = NA,
+              min=0
+            ),
+            textAreaInput(
+              inputId = ns("irr_cond_beam_characteristics"),
+              label = "Beam characteristics",
+              placeholder = "Beam quality indicators, filtration (X-rays), energy (Gamma rays), ..."
+            ),
+            selectInput(
+              ns("scoring_method"),
+              label = "Scoring method",
+              choices = c("Please choose"="", "manual", "auto")
+            ),
+            textInput(
+              inputId = ns("origin_curve"),
+              label = "Origin of the curve",
+              placeholder = "e.g. own, IAEA ..."
+            )
+          )
+        ))
     ),
     fluidRow(
       # Box: Stains color options ----
       box(
         width = 5,
         title = span(
-          "Stains color options",
+          "2. Stains color options",
           help_modal_button(
             ns("help_colors_data"),
             ns("help_colors_modal")
@@ -297,7 +387,7 @@ mod_estimation_trans_ui <- function(id, label) {
         # Box: Chromosome-color table ----
         box(
           width = 12,
-          title = "Chromosome data",
+          title = "3. Chromosome data",
           status = "primary",
           collapsible = TRUE,
           fluidRow(
@@ -335,7 +425,7 @@ mod_estimation_trans_ui <- function(id, label) {
       box(
         width = 5,
         title = span(
-          "Data input options",
+          "4. Data input options",
           help_modal_button(
             ns("help_cases_data"),
             ns("help_cases_data_modal")
@@ -399,11 +489,11 @@ mod_estimation_trans_ui <- function(id, label) {
             conditionalPanel(
               condition = "!input.load_case_data_check",
               ns = ns,
-              # numericInput(
-              #   ns("num_cases"),
-              #   label = "Number of cases",
-              #   value = 1
-              # ),
+              numericInput(
+                ns("num_cases"),
+                label = "Number of cases",
+                value = 1
+               ),
               numericInput(
                 ns("num_aberrs"),
                 label = "Maximum number of translocations per cell",
@@ -463,7 +553,7 @@ mod_estimation_trans_ui <- function(id, label) {
       col_7_inner(
         box(
           width = 12,
-          title = "Data input",
+          title = "5. Data input",
           status = "primary",
           collapsible = TRUE,
 
@@ -576,7 +666,7 @@ mod_estimation_trans_ui <- function(id, label) {
         box(
           width = 12,
           title = span(
-            "Dose estimation options",
+            "6. Dose estimation options",
             help_modal_button(
               ns("help_estimation_options"),
               ns("help_estimation_options_modal")
@@ -626,7 +716,6 @@ mod_estimation_trans_ui <- function(id, label) {
               )
             )
           ),
-
           # Type of exposure selection
           div(
             class = "side-widget-tall",
@@ -805,66 +894,18 @@ mod_estimation_trans_ui <- function(id, label) {
             class = "options-button",
             label = "Estimate dose"
           )
+        ),
+        col_12(
+          # tabBox: Estimation results ----
+          uiOutput(ns("estimation_results_ui"))
+
         )
       )
     ),
     fluidRow(
-      col_6_inner(
-        # tabBox: Estimation results ----
-        uiOutput(ns("estimation_results_ui")),
-
-        # Box: Export data and results ----
-        box(
-          width = 12,
-          title = span(
-            "Save results",
-            help_modal_button(
-              ns("help_fit_data_save"),
-              ns("help_fit_data_save_modal")
-            )
-          ),
-          status = "warning",
-          collapsible = TRUE,
-
-          # Help Modal
-          bsplus::bs_modal(
-            id = ns("help_fit_data_save_modal"),
-            title = "Help: Export results",
-            size = "large",
-            body = tagList(
-              # Contents
-              include_help("save/estimation_data_save_report.md")
-            )
-          ),
-
-          # Case description
-          textAreaInput(
-            inputId = ns("results_comments"),
-            label = "Comments",
-            placeholder = "Comments to be included on report"
-          ),
-
-          # Download report
-          downloadButton(
-            ns("save_report"),
-            class = "export-button side-widget-download",
-            label = "Download report"
-          ),
-          div(
-            class = "side-widget-format",
-            selectInput(
-              ns("save_report_format"),
-              label = NULL,
-              width = "85px",
-              choices = list(".pdf", ".docx"),
-              selected = ".pdf"
-            )
-          )
-        )
-      ),
       # Box: Plot curves ----
       box(
-        width = 6,
+        width = 12,
         title = "Curve plot",
         status = "success",
         collapsible = TRUE,
@@ -883,8 +924,70 @@ mod_estimation_trans_ui <- function(id, label) {
             ns("save_plot_format"),
             label = NULL,
             width = "75px",
-            choices = list(".png", ".pdf"),
-            selected = ".png"
+            choices = list(".jpg", ".png",".pdf"),
+            selected = ".jpg"
+          )
+        )
+      ),
+      # Box: Export data and results ----
+      box(
+        width = 6,
+        title = span(
+          "7. Save results",
+          help_modal_button(
+            ns("help_fit_data_save"),
+            ns("help_fit_data_save_modal")
+          )
+        ),
+        status = "warning",
+        collapsible = TRUE,
+
+        # Help Modal
+        bsplus::bs_modal(
+          id = ns("help_fit_data_save_modal"),
+          title = "Help: Export results",
+          size = "large",
+          body = tagList(
+            # Contents
+            include_help("save/estimation_data_save_report.md")
+          )
+        ),
+        # Case description
+        textAreaInput(
+          inputId = ns("results_comments"),
+          label = "Comments",
+          placeholder = "Comments to be included on report"
+        ),
+        downloadButton(
+          ns("save_data"),
+          class = "export-button side-widget-download",
+          label = "Save data"
+        ),
+        div(
+          class = "side-widget-format",
+          selectInput(
+            ns("save_data_format"),
+            label = NULL,
+            width = "75px",
+            choices =  list(".rds", ".xlsx"),
+            selected = ".rds"
+          )
+        ),
+
+        # Download report
+        downloadButton(
+          ns("save_report"),
+          class = "export-button side-widget-download",
+          label = "Download report"
+        ),
+        div(
+          class = "side-widget-format",
+          selectInput(
+            ns("save_report_format"),
+            label = NULL,
+            width = "85px",
+            choices = list(".pdf", ".docx"),
+            selected = ".pdf"
           )
         )
       )
